@@ -44,7 +44,9 @@ class Storage(driver.Base):
     def get_json(self, path):
         logger.info("get_json path:%s" % path)
         try:
-            return json.loads(self.get_unicode(path))
+            result = json.loads(self.get_unicode(path))
+            logger.info("get_json result:%s" % result)
+            return result
         except Exception as e:
             logger.error("get_json error:%s" % e)
             return []
